#!/usr/bin/python3

from enum import Enum, StrEnum
from dataclasses import dataclass

class Format(StrEnum):
    STANDARD       = "standard"
    MODERN         = "modern"
    PIONEER        = "pioneer"
    HISTORIC       = "historic"
    EXPLORER       = "explorer"
    TIMELESS       = "timeless"
    ALCHEMY        = "alchemy"
    PAUPER         = "pauper"
    LEGACY         = "legacy"
    VINTAGE        = "vintage"
    PENNY_DREADFUL = "penny_dreadful"
    COMMANDER_1V1  = "commander_1v1"
    COMMANDER      = "commander"

class Color(Enum):
    WHITE = 0
    BLUE  = 1
    BLACK = 2
    RED   = 3
    GREEN = 4

@dataclass(frozen=True)
class Archetype():
    name: str
    colors: list[Color]
    featuredCardNames: list[str]
    metagamePercentage: int
    numberOfDecks: int
    tabletopCost: int

def get_archetypes_for_format(mformat: Format) -> list[Archetype]:
    url = "https://www.mtggoldfish.com/metagame/" + mformat + "/full#paper"
    print(url)

def main():
    archetypes = get_archetypes_for_format(Format.PAUPER)
    print(archetypes)

if __name__ == "__main__":
    main()
